@@ -151,7 +151,6 @@ class Light(Feature):
             color_mode = None
             current_effect = None
             effect_list = None
-
         alias, methods = box_type_config[0]
         const_kwargs = dict(
             methods=methods,
@@ -398,13 +397,9 @@ class Light(Feature):
         max_val = max(elements)
         min_val = min(elements)
         if 0 > max_val or max_val > 255:
-            raise ValueError(
-                f"Max value in normalisation was outside range {max_val}."
-            )
+            raise ValueError(f"Max value in normalisation was outside range {max_val}.")
         elif min_val < 0:
-            raise ValueError(
-                f"Min value in normalisation was outside range {min_val}."
-            )
+            raise ValueError(f"Min value in normalisation was outside range {min_val}.")
         elif max_val == 0:
             return [255] * len(elements)
         return list(map(lambda x: round(x * 255 / max_val), elements))
@@ -584,6 +579,7 @@ class Light(Feature):
 
         if self.mask is not None:
             value = self.mask(value)
+
         await self.async_api_command("set", value)
 
     async def async_off(self) -> None:
